pub struct NamedStructure<Name = String, Args = usize, R: RepName = LibraryRep, Aind = AbstractIndex> {
pub structure: OrderedStructure<R, Aind>,
pub global_name: Option<Name>,
pub additional_args: Option<Args>,
}Expand description
A named structure is a structure with a global name, and a list of slots
It is useful when you want to shadow tensors, to nest tensor network contraction operations.
Fields
structure: OrderedStructure<R, Aind>global_name: Option<Name>additional_args: Option<Args>Implementations
Sourceimpl<Name, Args, R: RepName, Aind: AbsInd> NamedStructure<Name, Args, R, Aind>
impl<Name, Args, R: RepName, Aind: AbsInd> NamedStructure<Name, Args, R, Aind>
pub fn from_iter<I, T>( iter: T, name: Name, args: Option<Args>, ) -> PermutedStructure<Self>